/*
 * SWE Funktionsbibliothek Objektfilter
 * Copyright (C) 2011-2020 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 3 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.objfilter.interpreter;

/**
 * Repräsentation eines Fehlers der beim Parsen eines Filterausdrucks
 * aufgetreten ist.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class ParseError {

    /** die Zeile, an der Fehler aufgetreten ist. */
    private int line;
    /** die Position in der Zeile, an der Fehler aufgetreten ist. */
    private int position;
    /** die Fehlermeldung. */
    private String msg;

    /**
     * Erzeugt eine Instanz eines {@link ParseError}.
     *
     * @param line     die Zeile an der der Fehler erkannt wurde
     * @param position die Position in der Zeile an der der Fehler erkannt wurde
     * @param msg      die Fehlermeldung
     */
    public ParseError(int line, int position, String msg) {
        this.line = line;
        this.position = position;
        this.msg = msg;
    }

    @Override
    public final String toString() {
        return "Zeile " + line + ":" + position + " --> " + msg;
    }

}
